@@ -3,7 +3,7 @@ package Text::OutputFilter;
 use strict;
 use warnings;
 
-our $VERSION = "0.19";
+our $VERSION = "0.20";
 
 =head1 NAME
 
@@ -70,7 +70,7 @@ H.Merijn Brand <h.m.brand@procura.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2015 H.Merijn Brand for PROCURA B.V.
+Copyright (C) 2006-2016 H.Merijn Brand for PROCURA B.V.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
@@ -193,7 +193,8 @@ sub CLOSE
 {
     my $self = shift;
     my ($pfx, $io, $sub, $line) = @{$self}{qw( pfx io sb line )};
-    $line ne "" and print { $io } _Filter_ (0, $pfx, $sub, $line);
+    defined $line && $line ne "" and
+	print { $io } _Filter_ (0, $pfx, $sub, $line);
     $self->{closed} or close $io;
     $self->{line} = "";
     $self->{closed} = 1;
